@@ -10,10 +10,12 @@ https://www.sphinx-doc.org/en/master/usage/configuration.html
 import os
 import shutil
 import subprocess
+import sys
 
-import sphobjinv as soi
 from pkg_resources import get_distribution
 
+sys.path.insert(0, os.path.abspath("./usage"))  # for symplot
+
 # -- Project information -----------------------------------------------------
 project = "AmpForm"
 package = "ampform"
@@ -42,34 +44,6 @@ subprocess.call(
     shell=True,
 )
 
-# -- Convert sphinx object inventory -----------------------------------------
-inv = soi.Inventory()
-inv.project = "constraint"
-
-constraint_object_names = [
-    "Constraint",
-    "Domain",
-    "Problem",
-    "Solver",
-    "Variable",
-]
-for object_name in constraint_object_names:
-    inv.objects.append(
-        soi.DataObjStr(
-            name=f"{inv.project}.{object_name}",
-            domain="py",
-            role="class",
-            priority="1",
-            uri=f"{inv.project}.{object_name}-class.html",
-            dispname="-",
-        )
-    )
-
-text = inv.data_file(contract=True)
-ztext = soi.compress(text)
-soi.writebytes("constraint.inv", ztext)
-
-
 # -- General configuration ---------------------------------------------------
 master_doc = "index.md"
 source_suffix = {
@@ -117,6 +91,7 @@ autodoc_default_options = {
         [
             "__call__",
             "__eq__",
+            "__getitem__",
         ]
     ),
 }
@@ -162,6 +137,9 @@ nitpick_ignore = [
     ("py:class", "a set-like object providing a view on D's items"),
     ("py:class", "a set-like object providing a view on D's keys"),
     ("py:class", "an object providing a view on D's values"),
+    ("py:class", "ipywidgets.widgets.widget_float.FloatSlider"),
+    ("py:class", "ipywidgets.widgets.widget_int.IntSlider"),
+    ("py:class", "mpl_interactions.controller.Controls"),
     ("py:class", "numpy.typing._array_like._SupportsArray"),
     ("py:class", "numpy.typing._dtype_like._DTypeDict"),
     ("py:class", "numpy.typing._dtype_like._SupportsDType"),
@@ -172,40 +150,20 @@ nitpick_ignore = [
 # Intersphinx settings
 intersphinx_mapping = {
     "attrs": ("https://www.attrs.org/en/stable", None),
-    "constraint": (
-        "https://labix.org/doc/constraint/public",
-        "constraint.inv",
-    ),
-    "expertsystem": (
-        "https://pwa.readthedocs.io/projects/expertsystem/en/stable",
-        None,
-    ),
-    "graphviz": ("https://graphviz.readthedocs.io/en/stable", None),
-    "jsonschema": (
-        "https://python-jsonschema.readthedocs.io/en/latest",
-        None,
-    ),
+    "expertsystem": ("https://expertsystem.readthedocs.io/en/stable", None),
+    "ipywidgets": ("https://ipywidgets.readthedocs.io/en/stable", None),
     "matplotlib": ("https://matplotlib.org/stable/", None),
     "mpl_interactions": (
         "https://mpl-interactions.readthedocs.io/en/stable",
         None,
     ),
-    "mypy": ("https://mypy.readthedocs.io/en/stable", None),
     "numpy": ("https://numpy.org/doc/stable", None),
     "pandas": ("https://pandas.pydata.org/pandas-docs/stable", None),
     "pwa": ("https://pwa.readthedocs.io", None),
-    "pycompwa": ("https://compwa.github.io", None),
     "python": ("https://docs.python.org/3", None),
-    "qrules": (
-        "https://pwa.readthedocs.io/projects/qrules/en/stable",
-        None,
-    ),
+    "qrules": ("https://qrules.readthedocs.io/en/stable", None),
     "sympy": ("https://docs.sympy.org/latest", None),
-    "tensorwaves": (
-        "https://pwa.readthedocs.io/projects/tensorwaves/en/stable",
-        None,
-    ),
-    "tox": ("https://tox.readthedocs.io/en/stable", None),
+    "tensorwaves": ("https://tensorwaves.readthedocs.io/en/stable", None),
 }
 
 # Settings for autosectionlabel
